@@ -34,10 +34,12 @@ class MainView(WizardPage):
         self.main.add_wizard_page(self, "ObjectMigration", "Target Creation Options")
 
         label = mforms.newLabel("Select options for the creation of the migrated schema in the target\nMySQL server and click [Next >] to execute.")
+        label.set_name("Page Description")
         self.content.add(label, False, True)
 
         panel = mforms.newPanel(mforms.TitledBoxPanel)
         panel.set_title("Schema Creation")
+        panel.set_name("Schema Creation")
         self.content.add(panel, False, True)
 
         box = mforms.newBox(False)
@@ -46,6 +48,7 @@ class MainView(WizardPage):
 
         self._create_db = mforms.newCheckBox()
         self._create_db.set_text("Create schema in target RDBMS")
+        self._create_db.set_name("Create Schema")
         box.add(self._create_db, False, True)
 
         # spacer
@@ -53,16 +56,22 @@ class MainView(WizardPage):
 
         self._create_script = mforms.newCheckBox()
         self._create_script.set_text("Create a SQL script file")
+        self._create_script.set_name("Create a Script File")
         self._create_script.add_clicked_callback(self._toggle_sql_script)
         box.add(self._create_script, False, True)
         self._file_hbox = mforms.newBox(True)
         self._file_hbox.set_spacing(4)
-        self._file_hbox.add(mforms.newLabel("Script File:"), False, True)
+        label = mforms.newLabel("Script File:")
+        label.set_name("Script File")
+        self._file_hbox.add(label, False, True)
+        self._file_hbox.set_name("Script File")
         self._create_script_file = mforms.newTextEntry()
+        self._create_script_file.set_name("Script File Value")
         self._create_script_file.set_value(os.path.join(os.path.expanduser('~'), 'migration_script.sql'))
         self._file_hbox.add(self._create_script_file, True, True)
         button = mforms.newButton()
         button.set_text("Browse...")
+        button.set_name("Browse")
         button.add_clicked_callback(self._browse_files)
         self._file_hbox.add(button, False, True)
         box.add(self._file_hbox, False, True)
@@ -78,6 +87,7 @@ class MainView(WizardPage):
 
         self._keep_schema = mforms.newCheckBox()
         self._keep_schema.set_text("Keep schemas if they already exist. Objects that already exist will not be recreated or updated.")
+        self._keep_schema.set_name("Keep Schema")
         box.add(self._keep_schema, False, True)
 
         self._create_db.set_active(True)
@@ -146,10 +156,10 @@ you may correct them in the next step. Table data will be migrated at a later st
 
     def create_ui(self):
         self.clear_tasks()
-        self._script_task = self.add_task(self._create_script_task, "Create Script File")
-        self._db_task1 = self.add_task(self._connect_task, "Connect to Target Database")
-        self._db_task2 = self.add_task(self._validate_existing_schemata, "Perform Checks in Target")
-        self._db_task3 = self.add_threaded_task(self._create_task, "Create Schemas and Objects")
+        self._script_task = self.add_task(self._create_script_task, "Create Script File", "Create Script File")
+        self._db_task1 = self.add_task(self._connect_task, "Connect to Target Database", "Connect to Target Database")
+        self._db_task2 = self.add_task(self._validate_existing_schemata, "Perform Checks in Target", "Perform Checks in Target")
+        self._db_task3 = self.add_threaded_task(self._create_task, "Create Schemas and Objects", "Create Schemas and Objects")
 
     def page_activated(self, advancing):
         WizardProgressPage.page_activated(self, advancing)
@@ -237,12 +247,15 @@ class CreationReportView(WizardPage):
         text = """Scripts to create the target schema were executed. No data has been migrated yet. Review the creation report below 
 for errors or warnings. If there are any errors, you can manually fix the scripts and click [Recreate Objects] to retry 
 the schema creation or return to the Manual Editing page to correct them there and retry the target creation."""
-        self.content.add(mforms.newLabel(text), False, True)
+        description = mforms.newLabel(text)
+        description.set_name("Page Description")
+        self.content.add(description, False, True)
 
         hbox = mforms.newBox(True)
         hbox.set_spacing(12)
         hbox.set_homogeneous(True)
         self._tree = mforms.newTreeView(mforms.TreeFlatList)
+        self._tree.set_name("Script Results")
         self._tree.add_column(mforms.IconStringColumnType, "Object", 200, False)
         self._tree.add_column(mforms.IconStringColumnType, "Result", 600, False)
         self._tree.end_columns()
@@ -252,6 +265,7 @@ the schema creation or return to the Manual Editing page to correct them there a
 
         self._advbox = mforms.newPanel(mforms.TitledBoxPanel)
         self._advbox.set_title("SQL CREATE Script for Selected Object")
+        self._advbox.set_name("SQL IDE")
         box = mforms.newBox(False)
         self._code = mforms.newCodeEditor()
         self._code.set_language(mforms.LanguageMySQL)
@@ -262,6 +276,7 @@ the schema creation or return to the Manual Editing page to correct them there a
         vbox.set_spacing(8)
         self._comment_check = mforms.newCheckBox()
         self._comment_check.set_text("Comment out")
+        self._comment_check.set_name("Comment Out")
         self._comment_check.add_clicked_callback(self._comment_clicked)
         vbox.add(self._comment_check, False, True)
 
@@ -289,6 +304,7 @@ the schema creation or return to the Manual Editing page to correct them there a
 
         self._msgbox = mforms.newPanel(mforms.TitledBoxPanel)
         self._msgbox.set_title("Output Messages")
+        self._msgbox.set_name("Output Messages")
         box = mforms.newBox(False)
         box.set_padding(8)
         self._msgs = mforms.newTextBox(mforms.VerticalScrollBar)
