@@ -1,4 +1,4 @@
-# Copyright (c) 2016, 2018, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2016, 2019, Oracle and/or its affiliates. All rights reserved.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License, version 2.0,
@@ -104,8 +104,8 @@ class ImportProgressPage(WizardProgressPage):
     def __init__(self, owner):
         WizardProgressPage.__init__(self, owner, "Import Data")
 
-        self.add_task(self.prepare_import, "Prepare Import")
-        self.add_threaded_task(self.start_import, "Import data file")
+        self.add_task(self.prepare_import, "Prepare Import", "Prepare Import")
+        self.add_threaded_task(self.start_import, "Import data file", "Import Data Dile")
         self.module = None
         self.stop = None
         self.import_time = None
@@ -595,17 +595,17 @@ class SelectDestinationPage(WizardPage):
                     continue
                 db_list.append(dbname)
                 ok = rset.nextRow()
-            
-            rset = self.main.editor.executeManagementQuery(u"SHOW FULL TABLES FROM `%s`" % self.main.destination_table['schema'], 0)
-            if rset:
-                ok = rset.goToFirstRow()
-                while ok:
-                    if rset.stringFieldValue(1) == "BASE TABLE":
-                        table_name = to_unicode(rset.stringFieldValue(0)) if not compare_in_lowercase else to_unicode(rset.stringFieldValue(0)).lower()
-                        full_name = u"%s.%s" % (self.main.destination_table['schema'], table_name)
-                        self.table_list[full_name] = {'schema': self.main.destination_table['schema'], 'table': table_name} 
-                        
-                    ok = rset.nextRow()
+            if self.main.destination_table['schema']:
+                rset = self.main.editor.executeManagementQuery(u"SHOW FULL TABLES FROM `%s`" % self.main.destination_table['schema'], 0)
+                if rset:
+                    ok = rset.goToFirstRow()
+                    while ok:
+                        if rset.stringFieldValue(1) == "BASE TABLE":
+                            table_name = to_unicode(rset.stringFieldValue(0)) if not compare_in_lowercase else to_unicode(rset.stringFieldValue(0)).lower()
+                            full_name = u"%s.%s" % (self.main.destination_table['schema'], table_name)
+                            self.table_list[full_name] = {'schema': self.main.destination_table['schema'], 'table': table_name} 
+                            
+                        ok = rset.nextRow()
             
             self.destination_table_sel.clear()
             self.destination_table_sel.add_items(self.table_list.keys())
@@ -761,6 +761,7 @@ class SelectFileWizardPage(WizardPage):
 
         self.importfile_browse_btn = mforms.newButton()
         self.importfile_browse_btn.set_text("Browse...")
+        self.importfile_browse_btn.set_name("Browse")
         self.importfile_browse_btn.add_clicked_callback(self.importfile_browse)
         entry_box.add(self.importfile_browse_btn, False, False)
 
@@ -814,6 +815,7 @@ class PowerImportWizard(WizardForm):
         WizardForm.__init__(self, mforms.Form.main_form())
 
         self.editor = editor
+        self.set_min_size(-1, 650)
         
         self.formats = []
         self.formats.append(create_module("csv", editor, True))
